//go:build wasm

package instance

import "github.com/scaleway/scaleway-cli/v2/core"

func serverConsoleCommand() *core.Command {
	return nil
}
